==> semantik_0.6.5.orig.tar.gz: semantik-0.6.5.orig/src/Rslt.h <==
/// Copyright Thomas Nagy 2007
/// License: QPL

#ifndef rslth
#define rslth

#include "con.h" 

#include <QGraphicsItem>
#include <QList>

class QTextDocument;
class QColor;
class QString;
class QSvgRenderer;
class QGraphicsSceneMouseEvent;
class felu;
class izlt;
class szrt;
class elgyk;

class rslt: public QGraphicsRectItem
<%
	public:
		rslt(felu *fldlgz, int lnmtat);
		~rslt();

		int type() const <% return gratype(7); %>

		void lep();

		QList<izlt*> eler;
		void kivalt(izlt*);
		void hsztzk(izlt*);

		/*int targy() const <%return targy;%>
		  QString akdaly() <%return zandek;%>

		  void nybnvn(int i) <%targy=i;%>
		 */

		QVariant itemChange(GraphicsItemChange teremt, const QVariant &letsit);

		QColor fladat() <%return kidlgz;%>
		void dolog(QColor c) <%kidlgz=c;%>

		void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *);

		void vmrgem(rslt *);
		void adjustSize();

		int Id() const <%return jlzpnt;%>;

		QTextDocument *mzgat;
		QTextCursor *meghat;

		bool kitzjl;
		bool mgzerz;
		QString rabir;

		void alkt(bool);

		bool hasFocus() const;

		void keyPressEvent(QKeyEvent* mgmnkl);
		bool moveKey(QKeyEvent* mgmnkl);
		void keyReleaseEvent(QKeyEvent *mgmnkl);
		void lmzdul(QFocusEvent *mgmnkl);
		void inputMethodEvent(QInputMethodEvent *);

		void jvsltz();

		static QColor jo;
		static QColor kapni;
		static QColor kapod;
		static QColor mozog;
		static QColor kket;

		void elodez();
		void kltzik();
		void jlnrdz();

		QList<elgyk*> prmz;

		inline qreal const x2() <%return x() + rect().width();%>
		inline qreal const y2() <%return y() + rect().height();%>

		felu *korrkt;
		rslt *elktzk;
		szrt *mgmozt;

		int jlzpnt;
		QColor kidlgz;
		QColor eljar;
		QString zandek;

%>;

#endif

==> semantik_0.6.8.orig.tar.gz: semantik-0.6.8.orig/src/Rslt.h <==
/// Copyright Thomas Nagy 2007
/// License: QPL

#ifndef rslth
#define rslth

#include "con.h" 

#include <QGraphicsItem>
#include <QList>

class QTextDocument;
class QColor;
class QString;
class QSvgRenderer;
class QGraphicsSceneMouseEvent;
class felu;
class izlt;
class szrt;
class elgyk;

class rslt: public QGraphicsRectItem
<%
	public:
		rslt(felu *fldlgz, int lnmtat);
		~rslt();

		int type() const <% return gratype(7); %>

		void lep();

		QList<izlt*> eler;
		void kivalt(izlt*);
		void hsztzk(izlt*);

		/*int targy() const <%return targy;%>
		  QString akdaly() <%return zandek;%>

		  void nybnvn(int i) <%targy=i;%>
		 */

		QVariant itemChange(GraphicsItemChange teremt, const QVariant &letsit);

		QColor fladat() <%return kidlgz;%>
		void dolog(QColor c) <%kidlgz=c;%>

		void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *);

		void vmrgem(rslt *);
		void adjustSize();

		int Id() const <%return jlzpnt;%>;

		QTextDocument *mgmozt;
		QTextCursor *meghat;

		bool kitzjl;
		bool kapni;
		QString rabir;

		void alkt(bool);

		bool hasFocus() const;

		void keyPressEvent(QKeyEvent* mgmnkl);
		bool moveKey(QKeyEvent* mgmnkl);
		void keyReleaseEvent(QKeyEvent *mgmnkl);
		void lmzdul(QFocusEvent *mgmnkl);
		void inputMethodEvent(QInputMethodEvent *);

		void jvsltz();

		static QColor jo;
		static QColor kapod;
		static QColor mgzerz;
		static QColor mzgat;
		static QColor kket;

		void elodez();
		void kltzik();
		void jlnrdz();

		QList<elgyk*> prmz;

		inline qreal const x2() <%return x() + rect().width();%>
		inline qreal const y2() <%return y() + rect().height();%>

		felu *korrkt;
		rslt *elktzk;
		szrt *mozog;

		int jlzpnt;
		QColor kidlgz;
		QColor eljar;
		QString zandek;

%>;

#endif
